|
# of threads in Optimal Transport Package
|
|
4
|
396
|
March 27, 2022
|
|
Will Julia be more efficient than PyTorch
|
|
1
|
990
|
March 27, 2022
|
|
Extremely slow n-th root of float
|
|
11
|
886
|
March 27, 2022
|
|
Julia 3 times slower than Fortran reading integer data from ASCII file
|
|
14
|
1529
|
March 26, 2022
|
|
Type-instability because of @threads boxing variables
|
|
23
|
1903
|
March 25, 2022
|
|
Combining lots of DataFrames, best approach?
|
|
10
|
1351
|
March 25, 2022
|
|
How to preallocate a triangular matrix and overwrite it with cholesky!
|
|
9
|
632
|
March 25, 2022
|
|
Why does BenchmarkTools `@belapsed` make so many allocations?
|
|
2
|
1892
|
March 25, 2022
|
|
Advice to make getfield(::NamedTuple, ::Symbol) typestable
|
|
19
|
1355
|
March 25, 2022
|
|
Avoid runtime dispatch when overloading `isless()`
|
|
2
|
415
|
March 24, 2022
|
|
Differentialequations.jl - Solving ODE with time dependent parameter allocation friendly
|
|
2
|
1300
|
March 23, 2022
|
|
Updated CSV reader benchmarks?
|
|
4
|
731
|
March 23, 2022
|
|
Faster zeros with calloc
|
|
26
|
4350
|
March 23, 2022
|
|
Rowwise compuation in `InMemoryDatasets.jl` vs `DataFrames.jl`
|
|
2
|
782
|
March 23, 2022
|
|
StructArrays (for Complex arrays) and DifferentialEquations not working together
|
|
4
|
730
|
March 22, 2022
|
|
Large allocations for imported text files
|
|
2
|
365
|
March 22, 2022
|
|
Large Garbage Collection in for loop if slicing vector
|
|
10
|
731
|
March 22, 2022
|
|
`log` performance regression and JET failures
|
|
3
|
429
|
March 20, 2022
|
|
Why is `collect()` faster than a for loop in this numerical scheme? (corrected!)
|
|
25
|
1431
|
March 19, 2022
|
|
Trying to add kernels for Gaussian Process
|
|
0
|
447
|
March 19, 2022
|
|
Can this be made faster?
|
|
5
|
651
|
March 19, 2022
|
|
Buffer in running external program in loops
|
|
24
|
1551
|
March 18, 2022
|
|
Improving type inference for `x` where `Meta.isexpr(x, ...)`
|
|
4
|
527
|
March 18, 2022
|
|
Why is Julia's graphics system so slow?
|
|
32
|
8180
|
March 17, 2022
|
|
Why is this numerical scheme so much faster when using `collect()` than a for loop?
|
|
4
|
603
|
March 17, 2022
|
|
Define mul! for DiffEqArrayOperator
|
|
4
|
740
|
March 16, 2022
|
|
Why is the splat operator slow?
|
|
3
|
1487
|
March 15, 2022
|
|
getindex(A::AbstractArray, I...) slows down computations with array of type Array{Float64,2}
|
|
2
|
504
|
March 15, 2022
|
|
Slower summation of a series in Julia than in Python
|
|
10
|
1364
|
March 15, 2022
|
|
RemoteChannel for multiple-producer multiple-consumer
|
|
3
|
1211
|
March 15, 2022
|